#
# $Id: __init__.py,v 1.14 2005/10/04 17:33:09 admin Exp $
#
# Copyright (c) 2003, 2004, 2005 Dirk Datzert
# All rights reserved. Written by Dirk Datzert <dirk@datzert.de>
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. The name of the author may not be used to endorse or promote products
#    derived from this software without specific prior written permission
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

__doc__ = '''Product RenderableCharts'''
__version__='$Revision: 1.14 $'[11:-2]

from Products.PythonScripts.Utility import allow_module, allow_class

try:

	from ChartTemplate import ChartTemplate, \
			manage_addChartTemplateForm, \
			manage_addChartTemplate, \
			ADD_CHART_TEMPLATE_PERMISSION

	from ChartObject import ChartObject, \
			manage_addChartObjectForm, \
			manage_addChartObject, \
			ADD_CHART_OBJECT_PERMISSION

	from RenderableObject import \
			ADD_RENDERABLE_OBJECT_PERMISSION

	from Charts import *
	from Grids import *
	from Labels import *
	from Legends import *
	from Shapes import *

	modules = [ (HorizontalBarChartObject, manage_addHorizontalBarChart), \
				(VerticalBarChartObject, manage_addVerticalBarChart), \
				(HorizontalBarChart3DObject, manage_addHorizontalBarChart3D), \
				(VerticalBarChart3DObject, manage_addVerticalBarChart3D), \
				(HorizontalLineChartObject, manage_addHorizontalLineChart), \
				(HorizontalLineChart3DObject, manage_addHorizontalLineChart3D), \
				(SpiderChartObject, manage_addSpiderChart), \
				(LegendedPieObject, manage_addLegendedPie), \
				(PieObject, manage_addPie), \
				(Pie3DObject, manage_addPie3D), \
				(AreaLinePlotObject, manage_addAreaLinePlot), \
				(LinePlotObject, manage_addLinePlot), \
				(LinePlot3DObject, manage_addLinePlot3D), \
				(GridLinePlotObject, manage_addGridLinePlot), \
				(ScatterPlotObject, manage_addScatterPlot), \
				(SplitLinePlotObject, manage_addSplitLinePlot), \
				(DoughnutObject, manage_addDoughnut), \
				(GridObject, manage_addGrid), \
				(DoubleGridObject, manage_addDoubleGrid), \
				(LabelObject, manage_addLabel), \
				(LegendObject, manage_addLegend), \
				(LineObject, manage_addLine), \
				(RectObject, manage_addRect), \
				(ShadedRectObject, manage_addShadedRect), \
				(CircleObject, manage_addCircle), \
				(EllipseObject, manage_addEllipse), \
				(StringObject, manage_addString), \
			  ]

	allow_module('webdav.common')
	allow_module('reportlab.lib.colors')
	allow_module('reportlab.graphics.widgets.grids')
	allow_module('reportlab.graphics.widgets.markers')
	allow_module('reportlab.graphics.widgetbase')
	allow_module('reportlab.pdfbase.pdfmetrics')
	allow_module('Products.RenderableCharts.MyColors')
	
	def initialize(context):

		context.registerClass(
			ChartTemplate,
			permission   = ADD_CHART_TEMPLATE_PERMISSION,
			constructors = ( manage_addChartTemplateForm, manage_addChartTemplate ),
			icon='icons/chart.gif',
			meta_type = ChartTemplate.meta_type
			)

		context.registerBaseClass(ChartTemplate)

		context.registerClass(
			ChartObject,
			permission   = ADD_CHART_OBJECT_PERMISSION,
			constructors = ( manage_addChartObjectForm, manage_addChartObject ),
			icon='icons/chart.gif',
			meta_type = ChartObject.meta_type
			)

		context.registerBaseClass(ChartObject)

		for klass, manage_add in modules:
			context.registerClass(
					klass,
					permission   = ADD_RENDERABLE_OBJECT_PERMISSION,
					constructors = ( manage_add, manage_add ),
					icon         = 'icons/chart.gif',
					meta_type    = klass.meta_type,
					visibility	 = None
			)

			context.registerBaseClass(klass)

			ChartTemplate._meta_types.append ( klass.meta_type )

		try:
			from Products.ZBabel import ZBabelTag
		except:
			import NoBabelTag


except:
	
	import traceback
	traceback.print_exc()

#	vim:ts=4
